// Set up the SVG container dimensions
const margin = { top: 50, right: 50, bottom: 50, left: 50 };
const width = 800 - margin.left - margin.right;
const height = 400 - margin.top - margin.bottom;

// Append SVG to the chart-container div
const svg = d3
  .select('#chart-container')
  .append('svg')
  .attr('width', width + margin.left + margin.right)
  .attr('height', height + margin.top + margin.bottom)
  .append('g')
  .attr(
    'transform',
    `translate(${margin.left},${margin.top})`,
  );

// Fetch and process the data
d3.csv(
  'https://gist.githubusercontent.com/Sruthi1003/bfc5ed462be08a3677ab8fc6b0275b7a/raw/845b1502f2379a1e6e7f9694a1ea205973071bf4/Countrywages.csv',
)
  .then((data) => {
    const years = data.columns.slice(1);

    const xScale = d3
      .scaleBand()
      .domain(data.map((d) => d.Country))
      .range([0, width])
      .padding(0.1);

    const yScale = d3
      .scaleLinear()
      .domain([
        0,
        d3.max(data, (d) =>
          d3.max(years, (year) => +d[year]),
        ),
      ])
      .range([height, 0]);

    const area = d3
      .area()
      .x(
        (d) =>
          xScale(d.data.Country) + xScale.bandwidth() / 2,
      )
      .y0((d) => yScale(d[0]))
      .y1((d) => yScale(d[1]));

    const stack = d3.stack().keys(years);
    const stackedData = stack(data);

    svg
      .selectAll('path')
      .data(stackedData)
      .enter()
      .append('path')
      .attr('d', area)
      .attr('fill', (d, i) => d3.schemeCategory10[i]);

    // Add X axis
    svg
      .append('g')
      .attr('transform', `translate(0,${height})`)
      .call(d3.axisBottom(xScale))
      .selectAll('text')
      .style('text-anchor', 'end')
      .attr('transform', 'rotate(-45)');

    // Add Y axis
    svg.append('g').call(d3.axisLeft(yScale));

    // Add chart title
    svg
      .append('text')
      .attr('x', width / 2)
      .attr('y', -20)
      .attr('text-anchor', 'middle')
      .style('font-size', '16px')
      .text('Total wages by the country');
  })
  .catch((error) =>
    console.log('Error loading the data:', error),
  );
